==> haskell-hopenpgp-2.5.5-108-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.5.5
id: hOpenPGP-2.5.5-FKPx03CAHxo8T7IZQz91YQ
key: hOpenPGP-2.5.5-FKPx03CAHxo8T7IZQz91YQ
license: MIT
copyright: 2012-2016  Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/hOpenPGP/
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581)
category: Codec, Data
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
abi: 249d534497f5aa2276437bf36fca87a2
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hOpenPGP-2.5.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/hOpenPGP-2.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/hOpenPGP-2.5.5
hs-libraries: HShOpenPGP-2.5.5-FKPx03CAHxo8T7IZQz91YQ
depends:
    aeson-1.2.1.0-JssfvwcKPt8HWgsY2AQth
    attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j base-4.10.0.0
    base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH bytestring-0.10.8.2
    bzlib-0.5.0.5-2ACJ0eb5Hvh5CxJWPSOUm0 binary-0.8.5.1
    binary-conduit-1.2.5-1XQGZE4zXx2FjfQU0dhsBr
    conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz
    conduit-extra-1.1.16-KEf50o5RV3r5Z0A1OmC86V containers-0.5.10.2
    cryptonite-0.24-1eRB8onf2x1HH5rI2M7djb
    crypto-cipher-types-0.0.9-IMJAjxjit354Iejk8O3wjA
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    errors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    incremental-parser-0.2.5.1-Jc25lee9wKUDsEraXZSeU
    ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6
    lens-4.15.4-E9EXUzWE1ybSWx6AV1GcN
    memory-0.14.6-HxsAJFqa809Bv6WJsrwqao
    monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
    nettle-0.2.0-5OQKaXi9ewv7eiuuvBHHs6
    newtype-0.2-FGlcbwZJDWBDoQ1CjU9icp
    openpgp-asciiarmor-0.1-DNgDSO6BllCI3xi8PcohVQ
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    securemem-0.1.9-Jq2KvPH2Mxu14cB2XfkmWp
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    wl-pprint-extras-3.5.0.5-G9dZC3rqH9tFXqH3RBpGbU
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
abi-depends: aeson-1.2.1.0-JssfvwcKPt8HWgsY2AQth=ba26dc5029b1e3a2d7e2a3e61dfdb816
             attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=f0c2def3bf3035ee5fff7e67af1419bc
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=8eee912e61521dafabce3d6c55a8e0d0
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE=339c00834bb4e63000d8fbc198c7bd3f
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=ecad75526b40e3669fcd751d69f205cf
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             bzlib-0.5.0.5-2ACJ0eb5Hvh5CxJWPSOUm0=77451954907c1387d4a7ce92aca09a8e
             binary-0.8.5.1=44e4c28d2f38593047e3772473ecb87e
             binary-conduit-1.2.5-1XQGZE4zXx2FjfQU0dhsBr=484eb75bcbfafd83c841c910ee53b93e
             conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz=dd2c43243b87e5c01b7ff1794c1b6520
             conduit-extra-1.1.16-KEf50o5RV3r5Z0A1OmC86V=a9f3c490efc927253fa90ef0216b9585
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             cryptonite-0.24-1eRB8onf2x1HH5rI2M7djb=d02ab198c5c49165db40ebdbd565d8e9
             crypto-cipher-types-0.0.9-IMJAjxjit354Iejk8O3wjA=7a43d4fe3210bd7cab7fe93409272d36
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=b4f1dc33e75c56b9a2dc645c2701b72a
             errors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv=2ba397a02c23470552a8fbc98f17499e
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=5285d4c9a9fd47aab57774d045fde1ac
             incremental-parser-0.2.5.1-Jc25lee9wKUDsEraXZSeU=a536ea7fc7d1c8a0160eacc37a8d2890
             ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6=0efe6b7b628b075d22132b9309b8143d
             lens-4.15.4-E9EXUzWE1ybSWx6AV1GcN=f1f6791e3083ae915e7ff24d91214c74
             memory-0.14.6-HxsAJFqa809Bv6WJsrwqao=5aa9d77910d6888267534eeffbc4b2ec
             monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3=ff43fb11907d0ef437d2b2cf4c75d9b1
             nettle-0.2.0-5OQKaXi9ewv7eiuuvBHHs6=073f247ce20a0b26e2a0fa70153d5810
             newtype-0.2-FGlcbwZJDWBDoQ1CjU9icp=f4d715592d9d7c3b53feec8b93c63ef4
             openpgp-asciiarmor-0.1-DNgDSO6BllCI3xi8PcohVQ=eb081389a24db3ce28df24c2e2526cf2
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             securemem-0.1.9-Jq2KvPH2Mxu14cB2XfkmWp=47caf65048fddb2b140a8d8df4eaff69
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=f833729171d8aeedacf984b736ec248c
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=0183ddfce1aabaf9dbeb4c47b7a27d83
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe=1aab9551474f1298c1817f0c2788332b
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             wl-pprint-extras-3.5.0.5-G9dZC3rqH9tFXqH3RBpGbU=5fba3ec70d3d3becb6c8442488ce7be5
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=b376f34fdf020268b43dfcb638579ae4
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=06cb668c0e9e66cc22d17c21c1fa2e38
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hopenpgp-2.5.5-113-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.5.5
id: hOpenPGP-2.5.5-6DPOmAopVxaDuzq9Jgrdm4
key: hOpenPGP-2.5.5-6DPOmAopVxaDuzq9Jgrdm4
license: MIT
copyright: 2012-2016  Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/hOpenPGP/
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581)
category: Codec, Data
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
abi: 980fbba8e6d8722a0c716b54fe9ce56f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hOpenPGP-2.5.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/hOpenPGP-2.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/hOpenPGP-2.5.5
hs-libraries: HShOpenPGP-2.5.5-6DPOmAopVxaDuzq9Jgrdm4
depends:
    aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm base-4.10.0.0
    base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH bytestring-0.10.8.2
    bzlib-0.5.0.5-2ACJ0eb5Hvh5CxJWPSOUm0 binary-0.8.5.1
    binary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg
    conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1
    conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e containers-0.5.10.2
    cryptonite-0.24-8TqkyTTvSG93llKG92zgyl
    crypto-cipher-types-0.0.9-Ag2qT5Trp0k9htlCL7QBtN
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    errors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    incremental-parser-0.2.5.1-Jc25lee9wKUDsEraXZSeU
    ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    memory-0.14.7-CZTdOBCJoah1c0c3vYdFwT
    monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
    nettle-0.2.0-KH3IVC3z7k6Iexe8vMcruc
    newtype-0.2-FGlcbwZJDWBDoQ1CjU9icp
    openpgp-asciiarmor-0.1-KViK2NI5FGw2nv7QR7YcSH
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    securemem-0.1.9-IkOuAib5iR08lq4Le9fClQ
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    wl-pprint-extras-3.5.0.5-G9dZC3rqH9tFXqH3RBpGbU
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
abi-depends: aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn=de27a328e189bca785104a080be3af69
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=754c9623208b731856696d360a56d5ab
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=8eee912e61521dafabce3d6c55a8e0d0
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE=339c00834bb4e63000d8fbc198c7bd3f
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=ecad75526b40e3669fcd751d69f205cf
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             bzlib-0.5.0.5-2ACJ0eb5Hvh5CxJWPSOUm0=77451954907c1387d4a7ce92aca09a8e
             binary-0.8.5.1=44e4c28d2f38593047e3772473ecb87e
             binary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg=263ddc01c9f4ff96f7e103f83c45d2b4
             conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1=3708573cd3ea293480bf7666534b0844
             conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e=381f89239aa3aa92177e8b18b50111ab
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             cryptonite-0.24-8TqkyTTvSG93llKG92zgyl=6740aec73109c5ddadb2db4ccab3ea83
             crypto-cipher-types-0.0.9-Ag2qT5Trp0k9htlCL7QBtN=c7b09a269a2f1e823ada29485c1a82ba
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=b4f1dc33e75c56b9a2dc645c2701b72a
             errors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv=2ba397a02c23470552a8fbc98f17499e
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=5285d4c9a9fd47aab57774d045fde1ac
             incremental-parser-0.2.5.1-Jc25lee9wKUDsEraXZSeU=a536ea7fc7d1c8a0160eacc37a8d2890
             ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6=0efe6b7b628b075d22132b9309b8143d
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=e82338a07e0485545cf962061c874e46
             memory-0.14.7-CZTdOBCJoah1c0c3vYdFwT=2e00c0fd9579ae3612d6b6e3f4f8dc53
             monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3=ff43fb11907d0ef437d2b2cf4c75d9b1
             nettle-0.2.0-KH3IVC3z7k6Iexe8vMcruc=cf5e74a7ffcde922a5c46d48f08bdd23
             newtype-0.2-FGlcbwZJDWBDoQ1CjU9icp=f4d715592d9d7c3b53feec8b93c63ef4
             openpgp-asciiarmor-0.1-KViK2NI5FGw2nv7QR7YcSH=5f766d06732b9d1e51d952164cabce1b
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             securemem-0.1.9-IkOuAib5iR08lq4Le9fClQ=a4d58e5f02e1b3671ba392c2e4813e4f
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=f833729171d8aeedacf984b736ec248c
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=0183ddfce1aabaf9dbeb4c47b7a27d83
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe=1aab9551474f1298c1817f0c2788332b
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             wl-pprint-extras-3.5.0.5-G9dZC3rqH9tFXqH3RBpGbU=5fba3ec70d3d3becb6c8442488ce7be5
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=b376f34fdf020268b43dfcb638579ae4
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=06cb668c0e9e66cc22d17c21c1fa2e38
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
